Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var LevelKeys = []string{"level", "lvl", "severity"}
LevelKeys are field names that contain log level information.
var TimestampKeys = []string{"timestamp", "time", "ts", "t"}
TimestampKeys are field names that contain timestamp information.
Functions ¶
func Entry ¶
Entry formats a log entry for display. If humanize is true, timestamps and IDs are formatted for readability. If raw is true, the original raw line is returned. Highlights is an optional map of field names to background colors.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.